import { aws_s3 as s3, aws_logs as logs, aws_kinesis as kinesis } from 'aws-cdk-lib';
/**
 * Logging options
 */
export declare abstract class LoggingDestination {
    /**
     * Construct a logging destination for a S3 Bucket
     * @param bucket an s3 bucket
     */
    static s3(bucket: s3.IBucket): LoggingDestination;
    /**
     * Send to CLoudwatch
     * @param logGroup
     */
    static cloudwatch(logGroup: logs.ILogGroup): LoggingDestination;
    /**
     * Stream to Kinesis
     * @param stream
     */
    static kinesis(stream: kinesis.IStream): LoggingDestination;
    /**
    * A name of the destination
    */
    abstract readonly name: string;
    /**
     * An Arn of the destination
     */
    abstract readonly arn: string;
    /**
     * unique addr of the destination
     */
    abstract readonly addr: string;
    protected constructor();
}
